@@ -14,6 +14,8 @@ nc_var <- function(x, i) {
 #'@name nc_var
 #'@export
 nc_var.character <- function(x, i) {
+  if (nchar(x) < 1) stop("NetCDF source cannot be empty string")
+  
   nc <- RNetCDF::open.nc(x)
   on.exit(RNetCDF::close.nc(nc), add  = TRUE)
   nc_var(nc, i)
@@ -24,7 +26,7 @@ nc_var.character <- function(x, i) {
 nc_var.NetCDF <- function(x, i) {
   out <- RNetCDF::var.inq.nc(x, i)
   out$dimids <- NULL
-  faster_as_tibble(out)
+  tibble::as_tibble(out)
 }
 
 
